import { Context } from '../context';
import { ApiResponseBody } from '../api/response';
import { ITextRelevanceProvider } from '../utils/textRelevance';
export declare type CommandCallbackResult = ApiResponseBody;
export declare type CommandCallback = ((context: Context) => CommandCallbackResult) | ((context: Context) => Promise<CommandCallbackResult>);
export declare type CommandMatcher = ((ctx: Context) => boolean | number) | ((ctx: Context) => Promise<boolean | number>);
export declare type CommandDeclaration = CommandMatcher | string[] | string | RegExp;
interface CreateMatcherFromStringParams {
    relevanceProvider?: ITextRelevanceProvider;
}
export declare class Command {
    private readonly _callback;
    private readonly _matcher;
    constructor(matcher: CommandMatcher, callback: CommandCallback);
    getRelevance(context: Context): Promise<number>;
    run(context: Context): Promise<CommandCallbackResult>;
    static createCommand(declaration: CommandDeclaration, callback: CommandCallback): Command;
    static createMatcherFromString(pattern: string, params?: CreateMatcherFromStringParams): CommandMatcher;
    static createMatcherFromStrings(patterns: string[], params?: CreateMatcherFromStringParams): CommandMatcher;
    static createMatcherFromRegExp(regexp: RegExp): CommandMatcher;
    static createMatcherAlways(): CommandMatcher;
    static createMatcherNever(): CommandMatcher;
}
export {};
